# pyCatSim

PyCatSim is a toy Python package that simulates cats and their associated humans and environment. The package is meant to teach packaging techniques and proper documentation. But we won't stop you if you want to have some fun with virtual cats!

## Versions

See our [releases page](https://github.com/khider/pyCatSim/releases) for details on what's included in each version.

## Documentation

Online documentation is available through [readthedocs](https://pycatsim.readthedocs.io/en/latest/).

## Installation

The latest stable release is available through Pypi. We recommend using Anaconda or Miniconda with a dedicated environment. Full installation instructions are available in the [package documentation](https://pycatsim.readthedocs.io/en/latest/installation.html).

## Citation

If you use our code in any way, please [cite us](https://pycatsim.readthedocs.io/en/latest/citation.html)! You can use the "cite this repository" button at the top of the GitHub page for convenience. 

## Development

PyCatSim development takes place on [GitHub](https://github.com/khider/pyCatSim)

## License

The project is licensed under the [Apache 2.0 license](https://github.com/khider/pyCatSim/blob/main/LICENSE). Please refer to the file call license. If you use the code in publications, please credit the work using the citation file.

## Disclaimer

This material is based upon work supported by the National Science Foundation under Grant Number RISE-2324732. Any opinions, findings, and conclusions or recommendations expressed in this material are those of the investigators and do not necessarily reflect the views of the National Science Foundation.



